import os

PACKAGE = 'pypack'
LIBRARY = 'tgcore'

NAME        = PACKAGE + '.' + LIBRARY
VERSION     = '0.0.1'
LICENSE     = 'MIT'
URL         = 'https://github.com/pypack/pypack.tgcore'
GIT_URL     = 'https://github.com/pypack/pypack.tgcore'
DOC_URL     = 'http://pypack-tgcore.readthedocs.io/en/latest/'
DESCRIPTION = ''
LONG_DESCR  = ''
AUTHOR      = 'Giovanni Cardamone'
EMAIL       = 'g.cardamone2@gmail.com'
COPY        = '2018, Giovanni Cardamone'
LANG        = 'en'
KEYWORDS    = 'PyPack tgcore'
